:mod:`ordec.lib.base` --- Base cell library
===========================================

.. automodule:: ordec.lib.base
  :members:
  :undoc-members:
  :exclude-members: instances, netlist_ngspice, discoverable_instances
